@@ -35,14 +35,11 @@ Cross-platform supports for reading, writing, copying, deleting, etc... files fr
 import shutil
 import os
 from glob import glob
-import logging
 
 from newtools.optional_imports import s3fs
 from newtools.aws import S3Location
 from .doggo import FileDoggo
 
-logger = logging.getLogger("newtools.doggo.fs")
-
 
 class DoggoFileSystem:
     """
