@@ -69,6 +69,23 @@ class TestCachedQuery(BaseTest):
 
         self.assertIn('INFO:newtools.cached_query:secret = *********', cm.output)
 
+    def test_log_pep249_string_path(self):
+        q = CachedPep249Query(self.sqlite_db,
+                              cache_path=self.tempdir,
+                              sql_paths=self.sql_path,
+                              gzip=False)
+        self.set_timeouts(q)
+
+        with self.assertLogs("newtools.cached_query", level="INFO") as cm:
+            q.get_results(sql_file="test_select.sql",
+                          output_prefix="test_query_1_row",
+                          params={
+                              "secret": "my secret"
+                          }
+                          )
+
+        self.assertIn('INFO:newtools.cached_query:secret = *********', cm.output)
+
     def test_cache_pep249(self):
         q = CachedPep249Query(self.sqlite_db,
                               cache_path=self.tempdir,
