@@ -96,16 +96,36 @@ class TestDoggos(unittest.TestCase):
         os.remove(pth)
 
     def test_read_pq_local(self):
+        """read a local parquet"""
         fh = PandasDoggo()
         pth = os.path.join(self.base_path, 'parquet', 'data.parquet')
         df = fh.load(pth)
 
+    def test_read_pq_local_snappy(self):
+        pth = os.path.join(self.base_path, 'parquet', 'snappy', 'compressed.snappy.parquet')
+
+        fh = PandasDoggo()
+        df = fh.load_parquet(pth)
+        print(df.to_parquet(pth, index=0))
+
     def test_write_pq_local(self):
         fh = PandasDoggo()
         df = pd.read_csv(os.path.join(self.base_path, 'parquet', 'emails.csv'))
         fh.save_parquet(df, os.path.join(self.base_path, 'parquet', 'emails.parquet'))
         os.remove(os.path.join(self.base_path, 'parquet', 'emails.parquet'))
 
+    def test_write_pq_snappy(self):
+        pth_in = os.path.join(self.base_path, 'parquet', 'snappy', 'uncompressed.parquet')
+        pth_out = os.path.join(self.base_path, 'parquet', 'snappy', 'compressed.snappy.parquet')
+        pth_exp = os.path.join(self.base_path, 'parquet', 'snappy', 'writing_target.snappy.parquet')
+        fh = PandasDoggo()
+        df = pd.read_parquet(pth_in)
+        fh.save_parquet(df, pth_out)
+        r = pd.read_parquet(pth_out, engine='pyarrow')
+        exp = pd.read_parquet(pth_exp, engine='pyarrow')
+
+        pd.testing.assert_frame_equal(r, exp)
+
     def test_read_pq_local_with_args(self):
         fh = PandasDoggo()
         pth = os.path.join(self.base_path, 'parquet', 'data.parquet')
@@ -253,6 +273,7 @@ class TestDoggos(unittest.TestCase):
         obj.delete()
 
     def test_read_pq_s3(self):
+        """read a parquet from s3"""
         fh = PandasDoggo()
 
         df_s3 = fh.load_parquet('s3://07092018pqtest/data.parquet')
@@ -274,6 +295,22 @@ class TestDoggos(unittest.TestCase):
         obj.load()  # checks that it was written
         obj.delete()
 
+    def test_write_pq_s3_snappy(self):
+        df = pd.DataFrame({'e-mail': {0: 'n@gmail.com', 1: 'p@gmail.com', 2: 'h@gmail.com', 3: 's@gmail.com',
+                                      4: 'l@gmail.com', 5: 'v@gmail.com', 6: None},
+                           'number': {0: 0, 1: 1, 2: 0, 3: 0, 4: 1, 5: 0, 6: 0}})
+        pth = S3Location('deductive-tools-testing').join('generic', 'email_test_copy.parquet')
+
+        fh = PandasDoggo()
+
+        fh.save(df, pth, index=None, compression="snappy")
+
+        pd.testing.assert_frame_equal(fh.load_parquet(pth), df)
+
+        s3 = boto3.resource('s3')
+        obj = s3.Object(pth.bucket, pth.key)
+        obj.delete()
+
     def test_cant_guess_format(self):
         fh = PandasDoggo()
         with self.assertRaises(ValueError):
